hdlmake package
===============

Subpackages
-----------

.. toctree::

    hdlmake.action
    hdlmake.fetch
    hdlmake.tools
    hdlmake.util

Submodules
----------

hdlmake.dep_file module
-----------------------

.. automodule:: hdlmake.dep_file
    :members:
    :undoc-members:
    :show-inheritance:

hdlmake.new_dep_solver module
-------------------------

.. automodule:: hdlmake.new_dep_solver
    :members:
    :undoc-members:
    :show-inheritance:

hdlmake.env module
------------------

.. automodule:: hdlmake.env
    :members:
    :undoc-members:
    :show-inheritance:

hdlmake.manifest_parser module
------------------------------

.. automodule:: hdlmake.manifest_parser
    :members:
    :undoc-members:
    :show-inheritance:

hdlmake.module module
---------------------

.. automodule:: hdlmake.module
    :members:
    :undoc-members:
    :show-inheritance:

hdlmake.module_pool module
--------------------------

.. automodule:: hdlmake.module_pool
    :members:
    :undoc-members:
    :show-inheritance:

hdlmake.srcfile module
----------------------

.. automodule:: hdlmake.srcfile
    :members:
    :undoc-members:
    :show-inheritance:

hdlmake.vhdl_parser module
--------------------------

.. automodule:: hdlmake.vhdl_parser
    :members:
    :undoc-members:
    :show-inheritance:

hdlmake.vlog_parser module
--------------------------

.. automodule:: hdlmake.vlog_parser
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: hdlmake
    :members:
    :undoc-members:
    :show-inheritance:
